FirebaseParams enum

Inheritance
Available extensions

Values

screenName → const FirebaseParams
screenClass → const FirebaseParams
loginMethod → const FirebaseParams
signUpMethod → const FirebaseParams
contentType → const FirebaseParams
itemId → const FirebaseParams
method → const FirebaseParams
searchTerm → const FirebaseParams
level → const FirebaseParams
character → const FirebaseParams
levelName → const FirebaseParams
success → const FirebaseParams
score → const FirebaseParams
achievementId → const FirebaseParams
virtualCurrencyName → const FirebaseParams
itemName → const FirebaseParams
groupId → const FirebaseParams
currency → const FirebaseParams
value → const FirebaseParams
source → const FirebaseParams
medium → const FirebaseParams
campaign → const FirebaseParams
term → const FirebaseParams
content → const FirebaseParams
aclid → const FirebaseParams
cp1 → const FirebaseParams
adPlatform → const FirebaseParams
adSource → const FirebaseParams
adFormat → const FirebaseParams
adUnitName → const FirebaseParams
coupon → const FirebaseParams
paymentType → const FirebaseParams
shippingTier → const FirebaseParams
items → const FirebaseParams
tax → const FirebaseParams
shipping → const FirebaseParams
transactionId → const FirebaseParams
affiliation → const FirebaseParams
itemListId → const FirebaseParams
itemListName → const FirebaseParams
creativeName → const FirebaseParams
creativeSlot → const FirebaseParams
locationId → const FirebaseParams
promotionId → const FirebaseParams
promotionName → const FirebaseParams
propertyName → const FirebaseParams
propertyValue → const FirebaseParams
enabled → const FirebaseParams
adStorageConsentGranted → const FirebaseParams
analyticsStorageConsentGranted → const FirebaseParams
adPersonalizationSignalsConsentGranted → const FirebaseParams
adUserDataConsentGranted → const FirebaseParams
defaultParameters → const FirebaseParams
timeoutMilliseconds → const FirebaseParams
timeout → const FirebaseParams
emailAddress → const FirebaseParams
phoneNumber → const FirebaseParams
hashedEmailAddress → const FirebaseParams
hashedPhoneNumber → const FirebaseParams

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FirebaseParams>
A constant List of the values in this enum, in order of their declaration.