NoValueOperations enum

Inheritance
Available extensions

Values

showInApp → const NoValueOperations
showNudge → const NoValueOperations
resetContext → const NoValueOperations
setContext → const NoValueOperations
logout → const NoValueOperations
deleteUser → const NoValueOperations
enableSdk → const NoValueOperations
disableSdk → const NoValueOperations
enableDataTracking → const NoValueOperations
disableDataTracking → const NoValueOperations
enableDeviceIdTracking → const NoValueOperations
disableDeviceIdTracking → const NoValueOperations
enableAndroidIdTracking → const NoValueOperations
disableAndroidIdTracking → const NoValueOperations
enableAdIdTracking → const NoValueOperations
disableAdIdTracking → const NoValueOperations
requestPushPermission → const NoValueOperations
trackEvent → const NoValueOperations
registerForPush → const NoValueOperations
registerForProvisionalPush → const NoValueOperations
passFCMToken → const NoValueOperations
passPushKitToken → const NoValueOperations
passFCMPushPayload → const NoValueOperations
updatePermissionCount → const NoValueOperations
pushPermissionResponse → const NoValueOperations

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NoValueOperations>
A constant List of the values in this enum, in order of their declaration.