PauseAudio class

Inheritance

Constructors

PauseAudio({required String id})
PauseAudio.from(dynamic inputs)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
initiator ↔ Invokable?
getter/setter pairinherited
inputs Map?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(dynamic data, ScopeManager scopeManager) → dynamic
inherited
execute(BuildContext context, ScopeManager scopeManager) Future
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited