SingletonAudioPlayer class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(String id) Future<void>
play({required String id, required Source source, required double volume, required double balance, required Duration position}) Future<void>
resume(String id) Future<void>
seek(String id, Duration position) Future<void>
stop(String id) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SingletonAudioPlayer
no setter