SubscribeBluetoothCharacteristicsAction class

Inheritance

Constructors

SubscribeBluetoothCharacteristicsAction({Invokable? initiator, Map? inputs, EnsembleAction? onError, EnsembleAction? onComplete, EnsembleAction? onDataStream, required String? characteristicsId})
SubscribeBluetoothCharacteristicsAction.from({Invokable? initiator, dynamic payload})
factory
SubscribeBluetoothCharacteristicsAction.fromYaml({Invokable? initiator, Map? payload})
factory

Properties

bluetoothManager BluetoothManager
getter/setter pair
characteristicsId String?
final
hashCode int
The hash code for this object.
no setterinherited
initiator ↔ Invokable?
getter/setter pairinherited
inputs Map?
getter/setter pairinherited
onComplete EnsembleAction?
getter/setter pair
onDataStream EnsembleAction?
getter/setter pair
onError EnsembleAction?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(dynamic data, ScopeManager scopeManager) → dynamic
inherited
execute(BuildContext context, ScopeManager scopeManager) Future
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited