execute method
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
Implementation
@override
Future<bool> execute(BuildContext context, ScopeManager scopeManager) {
return EnsembleUtils.dismissBottomSheet(
scopeManager.dataContext.eval(payload),
context,
);
}