InvokableNetworkInfo class

Mixed-in types
  • Invokable

Constructors

InvokableNetworkInfo({String? wifiName, String? wifiIPv4, String? wifiIPv6, String? wifiSubmask, String? wifiGatewayIP, String? wifiBroadcast, String? wifiBSSID})

Properties

definition ↔ SourceSpan?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wifiBroadcast String?
getter/setter pair
wifiBSSID String?
getter/setter pair
wifiGatewayIP String?
getter/setter pair
wifiIPv4 String?
getter/setter pair
wifiIPv6 String?
getter/setter pair
wifiName String?
getter/setter pair
wifiSubmask String?
getter/setter pair

Methods

getList(Object obj) List?
inherited
getMap(Object obj) Map?
inherited
getMethod(dynamic method) Function?
inherited
getProperty(dynamic prop) → dynamic
inherited
getString(Object obj) String?
inherited
getters() Map<String, Function>
mark these functions as protected as we need the implementations, but discourage direct usages. Reasons:
override
hasGettableProperty(dynamic prop) bool
inherited
hasMethod(dynamic method) bool
inherited
hasSettableProperty(dynamic prop) bool
inherited
methods() Map<String, Function>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(dynamic prop, dynamic val) → void
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
setters() Map<String, Function>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited