ResendVerificationCodeAction class

Action to resend a phone verification code using the AuthContextManager.

Inheritance

Constructors

ResendVerificationCodeAction({Invokable? initiator, String? phoneNumber, required String resendToken, required String provider, required String method, EnsembleAction? onSuccess, EnsembleAction? onError})
ResendVerificationCodeAction.fromYaml({Invokable? initiator, Map? payload})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
initiator ↔ Invokable?
getter/setter pairinherited
inputs Map?
getter/setter pairinherited
method String
final
onError EnsembleAction?
final
onSuccess EnsembleAction?
final
phoneNumber String?
final
provider String
final
resendToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(dynamic data, ScopeManager scopeManager) → dynamic
inherited
execute(BuildContext context, ScopeManager scopeManager) Future<void>
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited