ShowToastAction class

Inheritance
Mixed-in types

Constructors

ShowToastAction({Invokable? initiator, ToastType? type, String? title, String? message, dynamic body, bool? dismissible, Alignment? alignment, int? duration, Map? payload, Map<String, dynamic>? styles})
ShowToastAction.fromMap(dynamic inputs)
factory
ShowToastAction.fromYaml({Map? payload})
factory

Properties

alignment Alignment?
final
body → dynamic
final
classList List<String>?
getter/setter pairinherited
className String?
getter/setter pairinherited
currentTheme String?
no getterinherited
definition ↔ SourceSpan?
getter/setter pairinherited
dismissible bool?
final
duration int?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pairinherited
idStyles Map<String, dynamic>?
getter/setter pairinherited
initiator ↔ Invokable?
getter/setter pairinherited
inlineStyles Map<String, dynamic>?
getter/setter pairinherited
inputs Map?
getter/setter pairinherited
message String?
final
payload Map?
final
runtimeStyles Map<String, dynamic>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleOverrides Map<String, dynamic>?
getter/setter pairinherited
styles Map<String, dynamic>?
getter/setter pair
stylesNeedResolving bool
getter/setter pairinherited
title String?
final
type ToastType?
getter/setter pair
widgetId String?
getter/setter pairinherited
widgetType String?
getter/setter pairinherited
widgetTypeStyles Map<String, dynamic>?
getter/setter pairinherited

Methods

eval(dynamic data, ScopeManager scopeManager) → dynamic
inherited
execute(BuildContext context, ScopeManager scopeManager) Future
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
override
getList(Object obj) List?
inherited
getMap(Object obj) Map?
inherited
getMethod(dynamic method) Function?
inherited
getProperty(dynamic prop) → dynamic
inherited
getString(Object obj) String?
inherited
getters() Map<String, Function>
mark these functions as protected as we need the implementations, but discourage direct usages. Reasons:
override
hasGettableProperty(dynamic prop) bool
inherited
hasMethod(dynamic method) bool
inherited
hasSettableProperty(dynamic prop) bool
inherited
methods() Map<String, Function>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveStyles(ScopeManager scopeManager, Invokable invokable, BuildContext context) → void
inherited
setProperty(dynamic prop, dynamic val) → void
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
setters() Map<String, Function>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited