DeepLinkManager class

managing deep linking into our app. Navigate to the screen if the custom scheme passes in the screenId

Inheritance

Constructors

DeepLinkManager()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() → void
navigate to screen if the deep link specifies a screenId param
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited