ActionType enum

Inheritance
Available extensions

Values

invokeAPI → const ActionType
executeAction → const ActionType
showBottomSheet → const ActionType
dismissBottomSheet → const ActionType
showBottomModal → const ActionType
dismissBottomModal → const ActionType
showDialog → const ActionType
dismissDialog → const ActionType
closeAllDialogs → const ActionType
startTimer → const ActionType
stopTimer → const ActionType
executeCode → const ActionType
showToast → const ActionType
getLocation → const ActionType
openUrl → const ActionType
openCamera → const ActionType
openFaceCamera → const ActionType
uploadFiles → const ActionType
pickFiles → const ActionType
connectWallet → const ActionType
authorizeOAuthService → const ActionType
notification → const ActionType
requestNotificationAccess → const ActionType
showLocalNotification → const ActionType
copyToClipboard → const ActionType
share → const ActionType
rateApp → const ActionType
openAppSettings → const ActionType
getPhoneContacts → const ActionType
getPhoneContactPhoto → const ActionType
checkPermission → const ActionType
saveKeychain → const ActionType
clearKeychain → const ActionType
readKeychain → const ActionType
setSecureStorage → const ActionType
getSecureStorage → const ActionType
clearSecureStorage → const ActionType
getDeviceToken → const ActionType
receiveIntent → const ActionType
connectSocket → const ActionType
disconnectSocket → const ActionType
messageSocket → const ActionType
disconnectSSE → const ActionType
updateBadgeCount → const ActionType
clearBadgeCount → const ActionType
callExternalMethod → const ActionType
invokeHaptic → const ActionType
callNativeMethod → const ActionType
deeplinkInit → const ActionType
authenticateByBiometric → const ActionType
setLocale → const ActionType
clearLocale → const ActionType
signInAnonymous → const ActionType
signInWithCustomToken → const ActionType
verifySignIn → const ActionType
signOut → const ActionType
dispatchEvent → const ActionType
executeConditionalAction → const ActionType
executeActionGroup → const ActionType
takeScreenshot → const ActionType
playAudio → const ActionType
stopAudio → const ActionType
pauseAudio → const ActionType
resumeAudio → const ActionType
seekAudio → const ActionType
logEvent → const ActionType
getNetworkInfo → const ActionType
connectToWifi → const ActionType
connectivityListener → const ActionType
deviceSecurity → const ActionType
bluetoothInit → const ActionType
bluetoothStartScan → const ActionType
bluetoothStopScan → const ActionType
bluetoothConnect → const ActionType
wakelock → const ActionType
bluetoothDisconnect → const ActionType
bluetoothSubscribeCharacteristic → const ActionType
bluetoothUnsubscribeCharacteristic → const ActionType
controlDeviceBackNavigation → const ActionType
openDrawer → const ActionType
closeDrawer → const ActionType
closeApp → const ActionType
saveFile → const ActionType
sendVerificationCode → const ActionType
validateVerificationCode → const ActionType
resendVerificationCode → const ActionType
initializeStripe → const ActionType
showPaymentSheet → const ActionType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ActionType>
A constant List of the values in this enum, in order of their declaration.