EnsembleAction class abstract

payload representing an Action to do (navigateToScreen, InvokeAPI, ..)

Implementers

Constructors

EnsembleAction({Invokable? initiator, Map? inputs})

Properties

hashCode int
The hash code for this object.
no setterinherited
initiator ↔ Invokable?
getter/setter pair
inputs Map?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(dynamic data, ScopeManager scopeManager) → dynamic
execute(BuildContext context, ScopeManager scopeManager) Future
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(dynamic action, {Invokable? initiator}) EnsembleAction?
fromActionType(ActionType actionType, {Invokable? initiator, Map? payload}) EnsembleAction?