execute method

Future execute(
  1. BuildContext context,
  2. ScopeManager scopeManager
)

TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)

Implementation

Future<dynamic> execute(BuildContext context, ScopeManager scopeManager) {
  // placeholder until all Actions are implemented
  return Future.value(null);
}