ExecuteCodeAction class

TODO: confirm codeBlockSpan

Inheritance

Constructors

ExecuteCodeAction({Invokable? initiator, Map? inputs, required String codeBlock, EnsembleAction? onComplete, required SourceSpan codeBlockSpan})
ExecuteCodeAction.fromYaml({Invokable? initiator, Map? payload})
factory

Properties

codeBlock String
getter/setter pair
codeBlockSpan ↔ SourceSpan
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initiator ↔ Invokable?
getter/setter pairinherited
inputs Map?
getter/setter pairinherited
onComplete EnsembleAction?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(dynamic data, ScopeManager scopeManager) → dynamic
inherited
execute(BuildContext context, ScopeManager scopeManager) Future
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited