NavigateScreenAction class

Inheritance

Constructors

factory
factory

Properties

asExternal bool
finalinherited
asModal bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
initiator ↔ Invokable?
getter/setter pairinherited
inputs Map?
getter/setter pairinherited
isExternal bool
finalinherited
onNavigateBack EnsembleAction?
getter/setter pair
options Map<String, dynamic>?
finalinherited
payload Map<String, dynamic>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
getter/setter pairinherited
transition Map<String, dynamic>?
getter/setter pairinherited

Methods

eval(dynamic data, ScopeManager scopeManager) → dynamic
inherited
execute(BuildContext context, ScopeManager scopeManager) Future
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited