APIProvider class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clone(
) → APIProvider -
dispose(
) → dynamic -
init(
String appId, Map< String, dynamic> config) → Future<void> -
invokeApi(
BuildContext context, YamlMap api, DataContext eContext, String apiName) → Future< Response> -
invokeMockAPI(
DataContext eContext, dynamic mock) → Future< Response> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited