Response class abstract

Implementers

Constructors

Response()

Properties

apiName String
getter/setter pair
apiState APIState
getter/setter pair
body ↔ dynamic
getter/setter pair
cookies Map<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>?
getter/setter pair
isOkay bool
getter/setter pair
reasonPhrase String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateState({required dynamic apiState}) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited