FirestoreAPIProvider class

Inheritance
Mixed-in types

Constructors

FirestoreAPIProvider()

Properties

firestore → FirebaseFirestore
no setter
firestoreApp FirestoreApp
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() APIProvider
override
convertFirestoreTypes(Map<String, dynamic> input) Map<String, dynamic>
dispose() → dynamic
override
evaluate(dynamic original, DataContext eContext) → dynamic
getDocument(DocumentSnapshot<Object?> doc) Map<String, dynamic>?
getDocuments(QuerySnapshot<Object?> snapshot) List<Map<String, dynamic>>
getErrorResponse(String apiName, dynamic e) FirestoreResponse
getOKResponse(String apiName, dynamic result) FirestoreResponse
init(String appId, Map<String, dynamic> config) Future<void>
override
invokeApi(BuildContext context, YamlMap apiMap, DataContext eContext, String apiName) Future<FirestoreResponse>
override
invokeMockAPI(DataContext eContext, dynamic mock) Future<Response>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeToApi(BuildContext context, YamlMap apiMap, DataContext eContext, String apiName, ResponseListener listener) Future<FirestoreResponse>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited