FirestoreApp class

Constructors

FirestoreApp(FirebaseFirestore firestore)

Properties

firestore → FirebaseFirestore
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getQuery(Map api, {bool isCollectionGroup = false}) → Query<Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performAddOperation(Map evaluatedApi) Future<DocumentReference<Object?>>
performDeleteOperation(Map evaluatedApi) Future<void>
performGetOperation(Map evaluatedApi) Future
performSetOperation(Map evaluatedApi) Future<void>
performUpdateOperation(Map evaluatedApi) Future<void>
toString() String
A string representation of this object.
inherited
unwrapObject(dynamic obj) → dynamic
unwrapObjects(List objs) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited