SSEAPIProvider class

Server-Sent Events (SSE) API Provider Handles streaming HTTP connections

Inheritance
Mixed-in types

Constructors

SSEAPIProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionCountForTesting int
no setter

Methods

clone() SSEAPIProvider
override
disconnect(String apiName) Future<void>
Disconnect a specific SSE connection by API name
dispose() → dynamic
override
init(String appId, Map<String, dynamic> config) Future<void>
override
invokeApi(BuildContext context, YamlMap api, DataContext eContext, String apiName) Future<Response>
override
invokeMockAPI(DataContext eContext, dynamic mock) Future<Response>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldReconnectForTesting(String apiName, SSEOptions options, int reconnectAttempts) bool
subscribeToApi(BuildContext context, YamlMap api, DataContext eContext, String apiName, ResponseListener listener) Future<Response>
override
toString() String
A string representation of this object.
inherited
trackSubscriptionForTesting(String apiName, StreamSubscription sub) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited