SSEOptions class

Configuration options for SSE connections

Constructors

SSEOptions({bool autoReconnect = true, int reconnectDelay = 1000, int maxReconnectAttempts = 5})
SSEOptions.fromYaml(YamlMap yaml, DataContext eContext)
factory

Properties

autoReconnect bool
final
hashCode int
The hash code for this object.
no setterinherited
maxReconnectAttempts int
final
reconnectDelay int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited