CdnAssetCacheFile class
Constructors
-
CdnAssetCacheFile({CdnAssetManifest? manifest, Map<
String, CdnAssetCacheState> cacheStates = const {}}) -
const
- CdnAssetCacheFile.fromJsonString(String jsonString)
-
factory
Properties
-
cacheStates
→ Map<
String, CdnAssetCacheState> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifest → CdnAssetManifest?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited