CdnAssetCacheState class

Constructors

CdnAssetCacheState({required String hash, required int downloadedAt})
const

Properties

downloadedAt int
final
hash String
Manifest hash used as the version/invalidation token.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value, {required String hash}) CdnAssetCacheState?