CdnAssetManifest class

Constructors

CdnAssetManifest({required Map<String, CdnAssetMetadata> assets, int? updatedAt})
const
CdnAssetManifest.fromJson(dynamic decoded)
factory
CdnAssetManifest.fromJsonString(String jsonString)
factory

Properties

assets Map<String, CdnAssetMetadata>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited