CdnAssetMetadata class

Constructors

CdnAssetMetadata({required String hash, required int size, String? contentType, int? updatedAt})
const

Properties

contentType String?
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
updatedAt int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) CdnAssetMetadata?