LocalDefinitionProvider class

Store all the definitions and assets locally together with the App

Inheritance

Constructors

LocalDefinitionProvider(String path, String appHome, {I18nProps? i18nProps, Locale? initialForcedLocale})

Properties

appConfig UserAppConfig?
getter/setter pairinherited
appHome String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
i18nProps I18nProps?
finalinherited
initialForcedLocale Locale?
getter/setter pairinherited
path String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppBundle({bool? bypassCache = false}) Future<AppBundle>
override
getAppConfig() UserAppConfig?
override
getCombinedAppBundle() Future<Map?>
getDefinition({String? screenId, String? screenName}) Future<ScreenDefinition>
override
getHomeScreenName() String?
override
getI18NDelegate({Locale? forcedLocale}) → FlutterI18nDelegate?
inherited
getSecrets() Map<String, String>
inherited
getSupportedLanguages() List<String>
inherited
getTranslationLoader(I18nProps i18nProps, {Locale? forcedLocale}) → FileTranslationLoader
override
init() Future<DefinitionProvider>
override
isArtifactRefreshEnabled() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAppLifecycleStateChanged(AppLifecycleState state) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited