DefinitionProvider class abstract

base definition provider

Implementers

Constructors

DefinitionProvider({Locale? initialForcedLocale})

Properties

hashCode int
The hash code for this object.
no setterinherited
initialForcedLocale Locale?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppBundle({bool? bypassCache = false}) Future<AppBundle>
getAppConfig() UserAppConfig?
getDefinition({String? screenId, String? screenName}) Future<ScreenDefinition>
getHomeScreenName() String?
getI18NDelegate({Locale? forcedLocale}) → FlutterI18nDelegate?
getSecrets() Map<String, String>
getSupportedLanguages() List<String>
init() Future<DefinitionProvider>
isArtifactRefreshEnabled() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAppLifecycleStateChanged(AppLifecycleState state) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(Map rootMap) DefinitionProvider