ConsoleLogProvider class

Inheritance

Constructors

ConsoleLogProvider()

Properties

ensembleAppId String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
options Map?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldAwait bool
getter/setter pairinherited

Methods

init({Map? options, String? ensembleAppId, bool shouldAwait = false}) Future<void>
override
log(Map<String, dynamic> config) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited