LogProvider class abstract
- Implementers
Constructors
Properties
- ensembleAppId ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- options ↔ Map?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldAwait ↔ bool
-
getter/setter pair
Methods
-
init(
{Map? options, String? ensembleAppId, bool shouldAwait = false}) → Future< void> -
log(
Map< String, dynamic> config) → Future<void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited