EBorderRadius class

Constructors

EBorderRadius.all(int val)
factory
EBorderRadius.only(int topLeft, int topRight, int bottomRight, int bottomLeft)
factory
EBorderRadius.three(int first, int second, int third)
factory
EBorderRadius.two(int first, int second)
factory

Properties

bottomLeft Radius
getter/setter pair
bottomRight Radius
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeft Radius
getter/setter pair
topRight Radius
getter/setter pair

Methods

getValue() BorderRadius
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited