EnsembleRouteObserver mixin
- Superclass constraints
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routeObserver
↔ RouteObserver<
PageRoute> -
latefinal
-
routeObservers
→ List<
NavigatorObserver> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCurrentRoute(
) → Route? -
initializeRouteObservers(
) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited