AuthContextManagerStub class

Implemented types

Constructors

AuthContextManagerStub()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSignedInUser() Future<AuthenticatedUser?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendVerificationCode({required String provider, required String method, required String phoneNumber, required int resendToken, required dynamic onSuccess(String verificationId, int? resendToken), required dynamic onError(String error)}) Future<void>
override
sendVerificationCode({required String provider, required String method, required String phoneNumber, required dynamic onSuccess(String verificationId, int? resendToken), required dynamic onError(String error)}) Future<void>
override
signOut() Future<void>
override
toString() String
A string representation of this object.
inherited
validateVerificationCode({required String provider, required String method, required String verificationId, required String smsCode, required dynamic onError(String error), required dynamic onSuccess(AuthenticatedUser, String idToken), required dynamic onVerificationFailure(String error)}) Future<AuthenticatedUser?>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited