BluetoothManagerStub class

Implemented types

Constructors

BluetoothManagerStub()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect({required String deviceId, required ServiceFoundCallback onServiceFound, required DataReceivedCallback connectionState, required bool autoConnect, required int timeout}) Future<void>
override
disconnect({required String deviceId}) → void
override
dispose() → void
override
init({required BuildContext context, Invokable? initiator, EnsembleAction? onDataStream}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startScan({required ScanResultCallback onScanResult}) Future
override
stopScan() Future<void>
override
subscribe(String characteristicId, DataReceivedCallback onDataReceive, {bool backgroundMode = false}) Future<void>
override
toString() String
A string representation of this object.
inherited
turnOn() Future<void>
override
unSubscribe(String characteristicId) Future<bool>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited