Contact class

Constructors

Contact({String id = '', String displayName = '', Uint8List? thumbnail, Uint8List? photo, bool isStarred = false, Name? name, List<Phone>? phones, List<Email>? emails, List<Address>? addresses, List<Organization>? organizations, List<Website>? websites})
Contact.fromJson(Map<String, dynamic> json)
factory

Properties

addresses List<Address>
getter/setter pair
displayName String
getter/setter pair
emails List<Email>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
isStarred bool
getter/setter pair
isUnified bool
getter/setter pair
name Name
getter/setter pair
organization Organization?
getter/setter pair
organizations List<Organization>
getter/setter pair
phones List<Phone>
getter/setter pair
photo Uint8List?
getter/setter pair
photoFetched bool
getter/setter pair
photoOrThumbnail Uint8List?
no setter
propertiesFetched bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail Uint8List?
getter/setter pair
thumbnailFetched bool
getter/setter pair
websites List<Website>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool withThumbnail = true, bool withPhoto = true}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited