ContactManagerStub class

Inheritance

Constructors

ContactManagerStub()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContactPhoto(String id, ContactPhotoSuccessCallback onSuccess, ContactPhotoErrorCallback onError) Future<void>
override
getPhoneContacts(ContactSuccessCallback onSuccess, ContactErrorCallback onError) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermission() Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited