Name class

Constructors

Name({String first = '', String last = '', String middle = '', String prefix = '', String suffix = '', String nickname = '', String firstPhonetic = '', String lastPhonetic = '', String middlePhonetic = ''})
Name.fromJson(Map<String, dynamic> json)
factory

Properties

first String
getter/setter pair
firstPhonetic String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
last String
getter/setter pair
lastPhonetic String
getter/setter pair
middle String
getter/setter pair
middlePhonetic String
getter/setter pair
nickname String
getter/setter pair
prefix String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited