Organization class

Constructors

Organization({String company = '', String title = '', String department = '', String jobDescription = '', String symbol = '', String phoneticName = '', String officeLocation = ''})
Organization.fromJson(Map<String, dynamic> json)
factory

Properties

company String
getter/setter pair
department String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jobDescription String
getter/setter pair
officeLocation String
getter/setter pair
phoneticName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
getter/setter pair
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited