DeferredLinkResponse class

Constructors

DeferredLinkResponse.error({required String errorCode, required String errorMessage})
DeferredLinkResponse.success({required dynamic result})

Properties

errorCode String
getter/setter pair
errorMessage String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
result ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited