LocationManager class abstract

Implementers

Constructors

LocationManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPermission() Future<LocationPermissionStatus>
distanceBetween(double startLat, double startLng, double endLat, double endLng) double
getLocation() Future<DeviceLocation>
getLocationStatus() Future<LocationStatus>
getPositionStream({int? distanceFilter}) Stream<LocationData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simplyGetLocation() Future<LocationData>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited