StripeManagerStub class

Stub implementation of StripeManager

Implemented types

Constructors

StripeManagerStub()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initializeStripe({String? publishableKey, String? stripeAccountId, String? merchantIdentifier}) Future<void>
Initialize Stripe with the given configuration
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showPaymentSheet({required String clientSecret, Map<String, dynamic>? configuration, BuildContext? context}) Future<void>
Show the Stripe payment sheet
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited