WifiManager class abstract

Implementers

Constructors

WifiManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String ssid, {bool saveNetwork = false}) Future<bool?>
connectByPrefix(String ssidPrefix, {bool saveNetwork = false}) Future<bool?>
connectToSecureNetwork(String ssid, String password, {bool isWep = false, bool isWpa3 = false, bool saveNetwork = false, bool isHidden = false}) Future<bool?>
connectToSecureNetworkByPrefix(String ssidPrefix, String password, {bool isWep = false, bool isWpa3 = false, bool saveNetwork = false}) Future<bool?>
disconnect() Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited