BottomNavBarItem class

Constructors

BottomNavBarItem({required Widget icon, required String text, required bool isCustom, Widget? activeIcon, bool isFloating = false, double? floatingMargin, bool? switchScreen = true, EnsembleAction? onTap, String? onTapHaptic})

Properties

activeIcon Widget?
getter/setter pair
floatingMargin double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon Widget
getter/setter pair
isCustom bool
getter/setter pair
isFloating bool
getter/setter pair
onTap EnsembleAction?
getter/setter pair
onTapHaptic String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
switchScreen bool?
getter/setter pair
text String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited