EnsembleBottomAppBar class

Inheritance

Constructors

EnsembleBottomAppBar({Key? key, required List<BottomNavBarItem> items, required int selectedIndex, double? height, dynamic margin, dynamic padding, BorderRadius? borderRadius, BoxShadow? boxShadow, Color? shadowColor, double? shadowRadius, double? shadowBlurRadius, BlurStyle? shadowStyle, double iconSize = 24.0, required Color backgroundColor, required Color color, required Color selectedColor, required NotchedShape notchedShape, required ValueChanged<int> onTabSelected, required bool isFloating, required FloatingAlignment floatingAlignment, VoidCallback? onFabTapped, int? floatingMargin})

Properties

backgroundColor Color
final
borderRadius BorderRadius?
final
boxShadow BoxShadow?
final
color Color
final
floatingAlignment FloatingAlignment
final
floatingMargin int?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
iconSize double
final
isFloating bool
final
items List<BottomNavBarItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → dynamic
final
notchedShape NotchedShape
final
onFabTapped VoidCallback?
final
onTabSelected ValueChanged<int>
final
padding → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color
final
selectedIndex int
final
shadowBlurRadius double?
final
shadowColor Color?
final
shadowRadius double?
final
shadowStyle BlurStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited