DragOptions class

Constructors

DragOptions({required EnsembleAction? onMaxSize, required EnsembleAction? onMinSize, required double maxSize, required double minSize, required bool isDraggable, required double initialSize, required bool expand, required bool snap, required bool showDragHandle, required List<double>? snapSizes})
DragOptions.fromYaml(YamlMap yamlMap, Invokable invokable)
factory

Properties

expand bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialSize double
getter/setter pair
isDraggable bool
getter/setter pair
maxSize double
getter/setter pair
minSize double
getter/setter pair
onMaxSize EnsembleAction?
getter/setter pair
onMinSize EnsembleAction?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDragHandle bool
getter/setter pair
snap bool
getter/setter pair
snapSizes List<double>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited