ActionResponse class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listeners
↔ Set<
Function> -
getter/setter pair
-
resultData
← Map<
String, dynamic> -
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
Function listener) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited