AnimatedAppBar class

Inheritance

Constructors

AnimatedAppBar({Key? key, dynamic automaticallyImplyLeading, dynamic leadingWidget, dynamic titleWidget, dynamic centerTitle, dynamic backgroundColor, dynamic surfaceTintColor, dynamic foregroundColor, dynamic elevation, dynamic shadowColor, dynamic titleBarHeight, dynamic backgroundWidget, dynamic animated, dynamic floating, dynamic pinned, dynamic collapsedBarHeight, dynamic expandedBarHeight, required ScrollController scrollController, dynamic curve, dynamic animationType, dynamic duration})

Properties

animated → dynamic
final
animationType → dynamic
final
automaticallyImplyLeading → dynamic
final
backgroundColor → dynamic
final
backgroundWidget → dynamic
final
centerTitle → dynamic
final
collapsedBarHeight → dynamic
final
curve → dynamic
final
duration → dynamic
final
elevation → dynamic
final
expandedBarHeight → dynamic
final
floating → dynamic
final
foregroundColor → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingWidget → dynamic
final
pinned → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
final
shadowColor → dynamic
final
surfaceTintColor → dynamic
final
titleBarHeight → dynamic
final
titleWidget → dynamic
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AnimatedAppBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited