PageState class

Inheritance
Mixed-in types

Constructors

PageState()

Properties

appLastPaused DateTime?
the last time the screen went to the background
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
footerWidget Widget?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
rootWidget Widget
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenLastPaused DateTime?
getter/setter pair
selectedPage int
getter/setter pair
wantKeepAlive bool
Whether the current instance should be kept alive.
no setteroverride
widget Page
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildFixedAppBar(SinglePageModel pageModel, bool hasDrawer) PreferredSizeWidget?
fixed AppBar
buildFixedPageContent(bool hasAppBar) Widget
buildScrollablePageContent(bool hasDrawer) Widget
buildSliverAppBar(SinglePageModel pageModel, bool hasDrawer) Widget?
create AppBar that is part of a CustomScrollView
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
override
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
override
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPop() → void
Called when the current route has been popped off.
inherited
didPopNext() → void
when a page is popped and we go back to this page
override
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPush() → void
Called when the current route has been pushed.
override
didPushNext() → void
Called when a new route has been pushed on top of this route, temporarily obscuring it.
override
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
didUpdateWidget(covariant Page oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
executeGlobalCode() → void
This is a callback because we need the widget to be first instantiate since the global code block may reference them. Once the global code block runs, only then we can continue the next steps for the widget creation process (propagate data scopes and execute bindings)
executeOnViewGroupUpdate() → void
this method executes if this screen is part of ViewGroup and onViewGroupUpdate is defined in View
getBody(bool hasAppBar) Widget
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
selectNavigationIndex(BuildContext context, MenuItem menuItem) → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateKeepAlive() → void
Ensures that any AutomaticKeepAlive ancestors are in a good state, by firing a KeepAliveNotification or triggering the KeepAliveHandle as appropriate.
inherited
useSafeArea() bool
determine if we should wraps the body in a SafeArea or not
wrapsInFlexible(Widget? backgroundWidget) Widget?
wraps the background in a FlexibleSpaceBar for automatic stretching and parallax effect.

Operators

operator ==(Object other) bool
The equality operator.
inherited