PageGroupWidget class
wrapper widget to enable a Page to get the navigation menu from its parent PageGroup We need this because the menu (i.e. drawer) is determined at the PageGroup level, but need to be injected under each child Page to render.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- InheritedWidget
- DataScopeWidget
- PageGroupWidget
Constructors
- PageGroupWidget({Key? key, required ScopeManager scopeManager, required Widget child, PageController? pageController})
-
const
Properties
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- debugLabel → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
final
-
final
- pageController → PageController?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeManager → ScopeManager
-
finalinherited
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant InheritedWidget oldWidget) → bool -
Whether the framework should notify widgets that inherit from this widget.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getPageController(
BuildContext context) → PageController? -
getScope(
BuildContext context) → ScopeManager? -
return the ScopeManager which includes the dataContext
TODO: have to repeat this function in DataScopeWidget?
override