ViewGroupNotifier class

Inheritance

Constructors

ViewGroupNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
payload Map<String, dynamic>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewIndex int
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
storeCurrentIndex() → void
Store ViewGroup index using a simple global key for persistence
toString() String
A string representation of this object.
inherited
updatePage(int index, {bool isReload = true, Map<String, dynamic>? payload}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited