BoxUtils class

Constructors

BoxUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildChildrenAndGap(int? gap, {List<Widget>? children, List<Widget>? templatedChildren}) List<Widget>
combine the children and templated children, plus the gap in between if specified
getChildrenFits(dynamic input) List<BoxFlex>
get the flex value for each child of FittedRow or FittedColumn