ItemTemplate class
- Inheritance
-
- Object
- BaseItemTemplate
- ItemTemplate
- Implementers
Constructors
-
ItemTemplate(dynamic data, String name, dynamic template, {String? indexId, dynamic initialValue, Map<
String, dynamic> ? inheritedStyles})
Properties
- data ↔ dynamic
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexId → String
-
finalinherited
-
inheritedStyles
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- initialValue ↔ dynamic
-
getter/setter pairinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- template → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
from(
Map? input) → ItemTemplate?