PullToRefreshOptions class

Annotations

Constructors

PullToRefreshOptions({RefreshIndicatorType? indicatorType, Duration? indicatorMinDuration, EdgeInsets? indicatorPadding})

Properties

hashCode int
The hash code for this object.
no setterinherited
indicatorMinDuration Duration?
getter/setter pair
indicatorPadding EdgeInsets?
getter/setter pair
indicatorType RefreshIndicatorType?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(dynamic input) PullToRefreshOptions?