TextScale class

Scale the text between the minFactor and maxFactor. Used by App theme and Text widget.

Constructors

TextScale({bool? enabled, double? minFactor, double? maxFactor})

Properties

enabled bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxFactor double?
getter/setter pair
minFactor double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(dynamic value) TextScale?