HasStyles mixin

Mixin applications

Properties

classList List<String>?
getter/setter pair
className String?
getter/setter pair
currentTheme String?
no getter
hashCode int
The hash code for this object.
no setterinherited
idStyles Map<String, dynamic>?
getter/setter pair
inlineStyles Map<String, dynamic>?
getter/setter pair
runtimeStyles Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleOverrides Map<String, dynamic>?
getter/setter pair
stylesNeedResolving bool
getter/setter pair
widgetId String?
getter/setter pair
widgetType String?
getter/setter pair
widgetTypeStyles Map<String, dynamic>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveStyles(ScopeManager scopeManager, Invokable invokable, BuildContext context) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toClassList(String? className) List<String>?