PageModel class abstract

Implementers

Constructors

PageModel()
PageModel.fromYaml(YamlMap data)
factory

Properties

actionsMap Map<String, YamlMap>?
getter/setter pair
apiMap Map<String, YamlMap>?
getter/setter pair
customViewDefinitions Map<String, dynamic>?
getter/setter pair
globalCode String?
getter/setter pair
globalCodeSpan ↔ SourceSpan?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
importedCode List<ParsedCode>?
getter/setter pair
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketData Map<String, EnsembleSocket>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

importToken → const String