ScreenPayload class

payload to pass to the Screen

Constructors

ScreenPayload({String? screenId, String? screenName, Map<String, dynamic>? arguments, PageType? pageType, bool isExternal = false})

Properties

arguments Map<String, dynamic>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isExternal bool
getter/setter pair
pageType PageType?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenId String?
getter/setter pair
screenName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited