ViewBehavior class

special behaviors for RootView (View) and Custom Views

Constructors

ViewBehavior({EnsembleAction? onLoad, EnsembleAction? onPause, EnsembleAction? onResume, EnsembleAction? onViewGroupUpdate})

Properties

hashCode int
The hash code for this object.
no setterinherited
onLoad EnsembleAction?
getter/setter pair
onPause EnsembleAction?
getter/setter pair
onResume EnsembleAction?
getter/setter pair
onViewGroupUpdate EnsembleAction?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited