util/debouncer library

Classes

Debouncer
Use this class to reduce excessive executions (e.g. API called too many times) using the run() method will ensure the execution happens only after the delay. Additional runs within this delay will reset the delay.