Debouncer class

Use this class to reduce excessive executions (e.g. API called too many times) using the run() method will ensure the execution happens only after the delay. Additional runs within this delay will reset the delay.

Constructors

Debouncer(Duration delay)

Properties

delay Duration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(VoidCallback action) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited