EnsembleUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dismissBottomSheet(
[Map? payload, BuildContext? context]) → Future< bool> - dismiss the Bottom Sheet if it is currently the top-most Route
-
dismissDialog(
[Map? payload, BuildContext? context]) → Future< bool> - dismiss any Dialog that is currently the top-most Route