EnsembleProperties class

Constructors

EnsembleProperties()

Properties

dateTimeAttributes Map<String, String>
final
generalAttributes Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
isNonInteractive bool
getter/setter pair
locationAttributes Map<String, Map<String, double>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAttribute(String key, dynamic value) → void
addAttributes(Map<String, dynamic> attributes) → void
addISODateTime(String key, String value) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNonInteractiveEvent() → void
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited