AvatarController class

Inheritance

Constructors

AvatarController()

Properties

alignment Alignment?
getter/setter pairinherited
backgroundColor Color?
getter/setter pairinherited
backgroundGradient LinearGradient?
getter/setter pairinherited
backgroundImage BackgroundImage?
getter/setter pairinherited
borderColor Color?
getter/setter pairinherited
borderGradient LinearGradient?
getter/setter pairinherited
borderRadius EBorderRadius?
getter/setter pairinherited
borderWidth int?
getter/setter pairinherited
boxShadow BoxShadowComposite?
getter/setter pairinherited
captureWebPointer bool?
getter/setter pairinherited
classList List<String>?
getter/setter pairinherited
className String?
getter/setter pairinherited
clipContent bool?
getter/setter pairinherited
colorFilter ColorFilterComposite?
getter/setter pair
currentTheme String?
no getterinherited
definition ↔ SourceSpan?
getter/setter pairinherited
elevation int?
getter/setter pairinherited
elevationBorderRadius EBorderRadius?
getter/setter pairinherited
elevationShadowColor Color?
getter/setter pairinherited
fit BoxFit?
getter/setter pair
flex int?
getter/setter pairinherited
flexMode FlexMode?
getter/setter pairinherited
groupTemplate GroupTemplate?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
height int?
getter/setter pairinherited
id String?
getter/setter pairinherited
idStyles Map<String, dynamic>?
getter/setter pairinherited
inlineStyles Map<String, dynamic>?
getter/setter pairinherited
margin EdgeInsets?
getter/setter pairinherited
name String?
getter/setter pair
nameTextStyle TextStyle?
getter/setter pair
onTap EnsembleAction?
getter/setter pair
onTapHaptic String?
getter/setter pair
opacity double?
getter/setter pairinherited
padding EdgeInsets?
getter/setter pairinherited
placeholderColor Color?
getter/setter pair
runtimeStyles Map<String, dynamic>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semantics EnsembleSemantics?
getter/setter pairinherited
source String?
getter/setter pair
stackPositionBottom int?
getter/setter pairinherited
stackPositionLeft int?
getter/setter pairinherited
stackPositionRight int?
getter/setter pairinherited
stackPositionTop int?
getter/setter pairinherited
styleOverrides Map<String, dynamic>?
getter/setter pairinherited
stylesNeedResolving bool
getter/setter pairinherited
testId String?
getter/setter pairinherited
textDirection TextDirection?
getter/setter pairinherited
toolTip Map<String, dynamic>?
getter/setter pairinherited
useGrayscaleFilter bool?
getter/setter pair
variant AvatarVariant?
getter/setter pair
visibilityTransitionDuration Duration?
getter/setter pairinherited
visible bool?
getter/setter pairinherited
widgetId String?
getter/setter pairinherited
widgetType String?
getter/setter pairinherited
widgetTypeStyles Map<String, dynamic>?
getter/setter pairinherited
width int?
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getList(Object obj) List?
inherited
getMap(Object obj) Map?
inherited
getMethod(dynamic method) Function?
inherited
getProperty(dynamic prop) → dynamic
inherited
getString(Object obj) String?
inherited
getters() Map<String, Function>
mark these functions as protected as we need the implementations, but discourage direct usages. Reasons:
override
hasBackground() bool
inherited
hasBackgroundSetters() Map<String, Function>
inherited
hasBorder() bool
inherited
hasBorderSetters() Map<String, Function>
inherited
hasBoxDecoration() bool
inherited
hasDimension() bool
inherited
hasGettableProperty(dynamic prop) bool
inherited
hasMethod(dynamic method) bool
inherited
hasPositions() bool
inherited
hasSettableProperty(dynamic prop) bool
inherited
methods() Map<String, Function>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
passthroughSetters() List<String>
a widget can tell the framework not to automatically evaluate its value while calling the setters can include the passthrough list here. This is useful if the widget wants to evaluate the value later (e.g. evaluate an Action's variables upon the action execution), or it wants to handle the binding listeners itself (e.g. item-template like)
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
requiresBox({required bool ignoresMargin, required bool ignoresPadding, required bool ignoresDimension}) bool
optimization. This is important to review if more properties are added
inherited
resolveStyles(ScopeManager scopeManager, Invokable invokable, BuildContext context) → void
inherited
setGroupAvatar(dynamic groupData) → void
setProperty(dynamic prop, dynamic val) → void
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
setters() Map<String, Function>
override
toString() String
A string representation of this object.
inherited
triggerListeners() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited