CellConfig class

Constructors

CellConfig({Color? backgroundColor, EdgeInsets? margin, EdgeInsets? padding, TextStyle? textStyle, Alignment? alignment, EBorderRadius? borderRadius, BoxShape? shape})

Properties

alignment Alignment?
getter/setter pair
backgroundColor Color?
getter/setter pair
borderRadius EBorderRadius?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets?
getter/setter pair
padding EdgeInsets?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape BoxShape?
getter/setter pair
textStyle TextStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited