RowSpanTemplate class
- Inheritance
-
- Object
- BaseItemTemplate
- ItemTemplate
- RowSpanTemplate
Constructors
- RowSpanTemplate({required String data, required String name, dynamic template, required SpanTemplate spanTemplate})
Properties
- data ↔ dynamic
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexId → String
-
finalinherited
-
inheritedStyles
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- initialValue ↔ dynamic
-
getter/setter pairinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spanTemplate → SpanTemplate
-
final
- template → dynamic
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited