SpanTemplate class

Constructors

SpanTemplate({required String start, required String end, dynamic widget, dynamic rowId})

Properties

end String
final
hashCode int
The hash code for this object.
no setterinherited
rowId → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start String
final
widget → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited