EnsembleBoxWrapper constructor

const EnsembleBoxWrapper({
  1. Key? key,
  2. required Widget widget,
  3. required EnsembleBoxController boxController,
  4. bool ignoresPadding = false,
  5. bool ignoresMargin = false,
  6. bool ignoresDimension = false,
  7. double? fallbackWidth,
  8. double? fallbackHeight,
  9. EBorderRadius? fallbackBorderRadius,
})

Implementation

const EnsembleBoxWrapper(
    {super.key,
    required this.widget,
    required this.boxController,

    // internal widget may want to handle padding itself (e.g. ListView so
    // its scrollbar lays on top of the padding and not the content)
    this.ignoresPadding = false,

    // sometimes our widget may register a gesture. Such gesture should not
    // include the margin. This allows it to handle the margin on its own.
    this.ignoresMargin = false,

    // width/height maybe applied at the child, or not applicable
    this.ignoresDimension = false,
    this.fallbackWidth,
    this.fallbackHeight,
    this.fallbackBorderRadius});