widget/helpers/controllers library

This class contains helper controllers for our widgets.

Classes

BoxController
TODO: Legacy - move to EnsembleBoxController Controller for anything with a Box around it (border, padding, shadow,...) This may be a widget itself (e.g Image), not necessary an actual Container with children
BoxShadowComposite
EnsembleBoxController
for Controllers that need Box properties
EnsembleSemantics
EnsembleWidgetController
Base Widget Controller
TapEnabledBoxController
TextStyleComposite
WidgetCompositeProperty
Widget property that have nested properties should be extending this, as this allows any setters on the nested properties to trigger changes
WidgetController
TODO: Legacy, transition to EnsembleWidgetController base Controller class for your Ensemble widget

Enums

FlexMode