BoxController class

TODO: Legacy - move to EnsembleBoxController Controller for anything with a Box around it (border, padding, shadow,...) This may be a widget itself (e.g Image), not necessary an actual Container with children

Inheritance
Implementers

Constructors

BoxController()

Properties

alignment Alignment?
getter/setter pairinherited
animation BoxAnimationComposite?
getter/setter pair
backgroundColor Color?
getter/setter pair
backgroundGradient LinearGradient?
getter/setter pair
backgroundImage BackgroundImage?
getter/setter pair
borderColor Color?
getter/setter pair
borderGradient LinearGradient?
getter/setter pair
borderRadius EBorderRadius?
getter/setter pair
borderWidth int?
getter/setter pair
boxShadow BoxShadowComposite?
getter/setter pair
captureWebPointer bool?
getter/setter pairinherited
classList List<String>?
getter/setter pairinherited
className String?
getter/setter pairinherited
clipContent bool?
getter/setter pair
currentTheme String?
no getterinherited
elevation int?
getter/setter pairinherited
elevationBorderRadius EBorderRadius?
getter/setter pairinherited
elevationShadowColor Color?
getter/setter pairinherited
expanded bool
getter/setter pairinherited
flex int?
getter/setter pairinherited
flexMode FlexMode?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
height int?
getter/setter pair
id String?
getter/setter pairinherited
idStyles Map<String, dynamic>?
getter/setter pairinherited
inlineStyles Map<String, dynamic>?
getter/setter pairinherited
label String?
getter/setter pairinherited
lastSetterProperty ↔ KeyValue?
getter/setter pairinherited
margin EdgeInsets?
getter/setter pair
opacity double?
getter/setter pairinherited
padding EdgeInsets?
getter/setter pair
runtimeStyles Map<String, dynamic>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semantics EnsembleSemantics?
getter/setter pairinherited
shadowColor Color?
getter/setter pair
shadowOffset Offset?
getter/setter pair
shadowRadius int?
getter/setter pair
shadowStyle BlurStyle?
getter/setter pair
stackPositionBottom int?
getter/setter pairinherited
stackPositionLeft int?
getter/setter pairinherited
stackPositionRight int?
getter/setter pairinherited
stackPositionTop int?
getter/setter pairinherited
styleOverrides Map<String, dynamic>?
getter/setter pairinherited
stylesNeedResolving bool
getter/setter pairinherited
testId String?
getter/setter pairinherited
textDirection TextDirection?
getter/setter pairinherited
toolTip Map<String, dynamic>?
getter/setter pairinherited
transform Matrix4?
getter/setter pair
visibilityTransitionDuration Duration?
getter/setter pairinherited
visible bool?
getter/setter pairinherited
widgetId String?
getter/setter pairinherited
widgetType String?
getter/setter pairinherited
widgetTypeStyles Map<String, dynamic>?
getter/setter pairinherited
width int?
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispatchChanges(KeyValue changedProperty) → void
inherited
dispose() → void
Discards any resources used by the object.
inherited
getBaseGetters() Map<String, Function>
inherited
getBaseMethods() Map<String, Function>
inherited
getBaseSetters() Map<String, Function>
override
getSemanticsLabel() String?
Returns the best available label for semantics/aria-label accessibility. Widgets should set label if they want to participate in accessibility fallback.
inherited
hasBackground() bool
hasBorder() bool
hasBoxDecoration() bool
hasBoxShadow() bool
hasDimension() bool
hasPositions() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
requiresBox({required bool ignoresMargin, required bool ignoresPadding, required bool ignoresDimension}) bool
optimization. This is important to review if more properties are added
resolveStyles(ScopeManager scopeManager, Invokable invokable, BuildContext context) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited