EnsembleSemantics class

Constructors

EnsembleSemantics({String? label, String? hint, String? role, required bool focusable})
EnsembleSemantics.fromYaml(Map<String, dynamic>? yamlMap)
factory

Properties

focusable bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hint String?
getter/setter pair
label String?
getter/setter pair
role String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited