EnsembleWidgetController class abstract

Base Widget Controller

Inheritance
Mixed-in types
Implementers

Constructors

EnsembleWidgetController()

Properties

alignment Alignment?
getter/setter pair
captureWebPointer bool?
getter/setter pair
classList List<String>?
getter/setter pairinherited
className String?
getter/setter pairinherited
currentTheme String?
no getterinherited
definition ↔ SourceSpan?
getter/setter pairinherited
elevation int?
getter/setter pair
elevationBorderRadius EBorderRadius?
getter/setter pair
elevationShadowColor Color?
getter/setter pair
flex int?
getter/setter pair
flexMode FlexMode?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
id String?
getter/setter pairoverride
idStyles Map<String, dynamic>?
getter/setter pairinherited
inlineStyles Map<String, dynamic>?
getter/setter pairinherited
opacity double?
getter/setter pair
runtimeStyles Map<String, dynamic>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semantics EnsembleSemantics?
getter/setter pair
stackPositionBottom int?
getter/setter pair
stackPositionLeft int?
getter/setter pair
stackPositionRight int?
getter/setter pair
stackPositionTop int?
getter/setter pair
styleOverrides Map<String, dynamic>?
getter/setter pairinherited
stylesNeedResolving bool
getter/setter pairinherited
testId String?
getter/setter pair
textDirection TextDirection?
getter/setter pair
toolTip Map<String, dynamic>?
getter/setter pair
visibilityTransitionDuration Duration?
getter/setter pair
visible bool?
getter/setter pair
widgetId String?
getter/setter pairinherited
widgetType String?
getter/setter pairinherited
widgetTypeStyles Map<String, dynamic>?
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getList(Object obj) List?
inherited
getMap(Object obj) Map?
inherited
getMethod(dynamic method) Function?
inherited
getProperty(dynamic prop) → dynamic
inherited
getString(Object obj) String?
inherited
getters() Map<String, Function>
mark these functions as protected as we need the implementations, but discourage direct usages. Reasons:
override
hasGettableProperty(dynamic prop) bool
inherited
hasMethod(dynamic method) bool
inherited
hasPositions() bool
hasSettableProperty(dynamic prop) bool
inherited
methods() Map<String, Function>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resolveStyles(ScopeManager scopeManager, Invokable invokable, BuildContext context) → void
inherited
setProperty(dynamic prop, dynamic val) → void
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
setters() Map<String, Function>
override
toString() String
A string representation of this object.
inherited
triggerListeners() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited