InputFieldHelper class
Common utilities and methods for input fields
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addEndingWidget(
InputDecoration decoration, dynamic endingWidget, ScopeManager? scopeManager) → InputDecoration -
createInputDoneButton(
BuildContext context) → Widget - Create an InputDoneButton widget
-
createTextFormField(
{required Key? key, required TextEditingController controller, required FocusNode focusNode, required bool validateOnUserInteraction, String? validator(String?)?, required List< TextInputFormatter> inputFormatters, required bool? multiline, required int? minLines, required int? maxLines, required int? maxLength, required MaxLengthEnforcement? maxLengthEnforcement, required bool enabled, required bool? readOnly, required bool selectable, required dynamic onChanged(String)?, required dynamic onFieldSubmitted(String)?, required dynamic onTapOutside(PointerDownEvent)?, required TextStyle? textStyle, required List<String> ? autofillHints, required InputDecoration decoration, required TextInputAction? keyboardAction, required TextInputType? keyboardType, dynamic onTap()?, bool obscureText = false, bool enableSuggestions = true, bool autocorrect = true}) → TextFormField - Create a common TextFormField with shared configuration
-
executeDelayedAction(
BuildContext context, EnsembleAction action, dynamic widget, Debouncer debouncer) → void - Execute a delayed action with debouncer
-
getCommonSetters(
dynamic widget, BaseInputController controller) → Map< String, Function> - Common setters for input fields
-
getKeyboardAction(
dynamic value) → TextInputAction? - Get the appropriate keyboard action based on string value
-
getKeyboardType(
String? inputType) → TextInputType? - Set appropriate TextInputType based on input type
-
getKeyPressDebouncer(
Debouncer? currentDebouncer, Duration? lastDuration, Duration newDuration) → Debouncer - Get or create a debouncer with the appropriate duration
-
getMaxLengthEnforcement(
String? value) → MaxLengthEnforcement? - Get MaxLengthEnforcement from string value
-
isMultiline(
bool? multilineFlag, int? maxLines) → bool - Check if input should be multiline
-
validateInput(
String? value, bool required, String? requiredMessage, InputValidator? validator) → String? - Build common validator function for input fields