TooltipData class

Constructors

TooltipData({required String message, TooltipStyleComposite? styles, EnsembleAction? onTriggered})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
onTriggered EnsembleAction?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles TooltipStyleComposite?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from(Map<String, dynamic>? data, ChangeNotifier controller) TooltipData?