widget/helpers/widgets library

This class contains common widgets for use with Ensemble widgets.

Classes

ClearableInput
Display a Text content followed by a clear icon. Clicking the icon will invoke the callback. Note that this is a StatelessWidget, so clearing out the value is the responsibility of the parent widget who uses this.
GradientBoxBorder
TapOverlay
a wrapper around a widget and enable Tap action.

Typedefs

TapOverlayFunc = void Function()