GradientBoxBorder class

Inheritance
Mixed-in types

Constructors

GradientBoxBorder({required LinearGradient gradient, required double width})
const

Properties

bottom BorderSide
no setterinherited
dimensions EdgeInsetsGeometry
The widths of the sides of this border represented as an EdgeInsets.
no setteroverride
gradient LinearGradient
final
hashCode int
The hash code for this object.
no setterinherited
isUniform bool
no setterinherited
preferPaintInterior bool
Reports whether paintInterior is implemented.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top BorderSide
no setterinherited
width double
final

Methods

add(ShapeBorder other, {bool reversed = false}) BoxBorder?
Attempts to create a new object that represents the amalgamation of this border and the other border.
inherited
getInnerPath(Rect rect, {TextDirection? textDirection}) Path
Create a Path that describes the inner edge of the border.
inherited
getOuterPath(Rect rect, {TextDirection? textDirection}) Path
Create a Path that describes the outer edge of the border.
inherited
lerpFrom(ShapeBorder? a, double t) ShapeBorder?
Linearly interpolates from another ShapeBorder (possibly of another class) to this.
inherited
lerpTo(ShapeBorder? b, double t) ShapeBorder?
Linearly interpolates from this to another ShapeBorder (possibly of another class).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Rect rect, {TextDirection? textDirection, BoxShape shape = BoxShape.rectangle, BorderRadius? borderRadius}) → void
Paints the border within the given Rect on the given Canvas.
override
paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) → void
Paint a canvas with the appropriate shape.
inherited
paintRect(Canvas canvas, Rect rect, LinearGradient gradient, double width) → void
inherited
paintRRect(Canvas canvas, Rect rect, BorderRadius borderRadius, LinearGradient gradient, double width) → void
inherited
scale(double t) ShapeBorder
Creates a copy of this border, scaled by the factor t.
override
toString() String
A string representation of this object.
inherited

Operators

operator +(ShapeBorder other) ShapeBorder
Creates a new border consisting of the two borders on either side of the operator.
inherited
operator ==(Object other) bool
The equality operator.
inherited