EnsembleImageCropperState class

Inheritance
Mixed-in types

Constructors

EnsembleImageCropperState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
currentShape → CustomCropShape
final
hashCode int
The hash code for this object.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
placeholder Widget
getter/setter pair
placeholderColors List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeManager ScopeManager?
getter/setter pairinherited
widget EnsembleImageCropper
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildImageProvider(String source, BoxFit? fit) ImageProvider<Object>
buildNonSvgImageProvider(String source, BoxFit? fit) ImageProvider<Object>
buildSvgImageProvider(String source, BoxFit? fit) → Svg
buildWidget(BuildContext context) Widget
build your widget here
override
capitalizeFirstLetter(String? value) String?
changeState() → void
inherited
cropImage() Future<void>
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant EnsembleImageCropper oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getPlaceholder() Widget
initState() → void
Called when this object is inserted into the tree.
override
isSvg() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resolveStylesIfUnresolved(BuildContext context) → void
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited