PositionedCircleSliderTickMarkShape class
- Inheritance
-
- Object
- SliderTickMarkShape
- PositionedCircleSliderTickMarkShape
Constructors
- PositionedCircleSliderTickMarkShape({required double tickMarkRadius, double verticalOffset = 0.0})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tickMarkRadius → double
-
final
- verticalOffset → double
-
final
Methods
-
getPreferredSize(
{required SliderThemeData sliderTheme, required bool isEnabled}) → Size -
Returns the preferred size of the shape.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
PaintingContext context, Offset center, {required RenderBox parentBox, required SliderThemeData sliderTheme, required Animation< double> enableAnimation, required TextDirection textDirection, required Offset thumbCenter, bool isEnabled = true}) → void -
Paints the slider track.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited