RadioState class
- Inheritance
-
- Object
- State<
RadioButton> - BaseWidgetState<
RadioButton> - EWidgetState<
RadioButton> - FormFieldWidgetState<
RadioButton> - RadioState
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- formFieldTextStyle → TextStyle
-
return the TextStyle for a form field (TextField, ....)
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputDecoration → InputDecoration
-
return a default InputDecoration if the controller is a FormField
Note that all fields here are inherited from InputDecorationTheme
which is defined at the Ensemble theme level. Hence only override
the attributes that are specified manually by the user at each input.
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeManager ↔ ScopeManager?
-
getter/setter pairinherited
-
validatorKey
→ GlobalKey<
FormFieldState> -
finalinherited
- widget → RadioButton
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
buildWidget(
BuildContext context) → Widget -
build your widget here
override
-
changeState(
) → void -
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant RadioButton oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
initState(
) → void -
Called when this object is inserted into the tree.
inherited
-
isEnabled(
) → bool -
return the field's enabled, fallback to parent Form's enabled,
then fallback to TRUE
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
resolveStylesIfUnresolved(
BuildContext context) → void -
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
shouldShowLabel(
) → bool -
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited