widget/radio/radio_button_controller library

Classes

RadioButtonController
A controller that keeps track of all the RadioButtons within a page. RadioButtons with the same groupId will reference the same instance of this controller