EnsembleStaggeredGrid class
- Inheritance
-
- Mixed-in types
-
Methods
-
createElement()
→ StatefulElement
-
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState()
→ State<StatefulWidget>
-
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
getList(Object obj)
→ List?
-
inherited
-
getMap(Object obj)
→ Map?
-
inherited
-
getMethod(dynamic method)
→ Function?
-
inherited
-
getProperty(dynamic prop)
→ dynamic
-
inherited
-
getString(Object obj)
→ String?
-
inherited
-
getters()
→ Map<String, Function>
-
mark these functions as protected as we need the implementations,
but discourage direct usages.
Reasons:
override
-
hasGettableProperty(dynamic prop)
→ bool
-
inherited
-
hasMethod(dynamic method)
→ bool
-
inherited
-
hasSettableProperty(dynamic prop)
→ bool
-
inherited
-
initChildren({List<WidgetModel>? children, Map? itemTemplate})
→ void
-
override
-
methods()
→ Map<String, Function>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
passthroughSetters()
→ List<String>
-
a widget can tell the framework not to automatically evaluate its value
while calling the setters can include the passthrough list here.
This is useful if the widget wants to evaluate the value later (e.g.
evaluate an Action's variables upon the action execution), or it wants
to handle the binding listeners itself (e.g. item-template like)
inherited
-
setProperty(dynamic prop, dynamic val)
→ void
-
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
-
setters()
→ Map<String, Function>
-
override
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited