EnsembleStaggeredGridState class
- Inheritance
-
- Mixed-in types
-
Methods
-
activate()
→ void
-
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
inherited
-
buildChild(WidgetModel model)
→ Widget
-
inherited
-
buildChildren(List<WidgetModel> models, {ScopeManager? preferredScopeManager})
→ List<Widget>
-
inherited
-
buildItems()
→ List<Widget>
-
-
buildSingleWidget(ScopeManager parentScope, ItemTemplate itemTemplate, {required int itemIndex, required dynamic itemData, Key? key})
→ DataScopeWidget
-
inherited
-
buildWidget(BuildContext context)
→ Widget
-
build your widget here
override
-
buildWidgetForIndex(BuildContext context, List dataList, ItemTemplate itemTemplate, int itemIndex)
→ DataScopeWidget?
-
inherited
-
buildWidgetsFromTemplate(BuildContext context, List dataList, ItemTemplate itemTemplate)
→ List<DataScopeWidget>?
-
inherited
-
changeState()
→ void
-
inherited
-
deactivate()
→ void
-
Called when this object is removed from the tree.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
didChangeDependencies()
→ void
-
Called when a dependency of this State object changes.
override
-
didUpdateWidget(covariant EnsembleStaggeredGrid oldWidget)
→ void
-
Called whenever the widget configuration changes.
inherited
-
dispose()
→ void
-
Called when this object is removed from the tree permanently.
inherited
-
initState()
→ void
-
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble()
→ void
-
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
registerItemTemplate(BuildContext context, BaseItemTemplate itemTemplate, {required Function onDataChanged})
→ void
-
inherited
-
resolveStylesIfUnresolved(BuildContext context)
→ void
-
inherited
-
setState(VoidCallback fn)
→ void
-
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited