ChartDefaults mixin
- Mixin applications
Properties
- borderData → FlBorderData
-
no setter
- gridData → FlGridData
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineTouchData → LineTouchData
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bottomTitles(
List< String> labels) → SideTitles -
leftTitles(
) → SideTitles -
leftTitleWidgets(
double value, TitleMeta meta) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
titlesData(
List< String> labels) → FlTitlesData -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited