ImageNode class

Inheritance

Constructors

ImageNode(String name, String imgPath, dynamic size, {dynamic position, dynamic subtree})

Properties

hashCode int
The hash code for this object.
no setterinherited
image Image?
getter/setter pair
imgPath String
getter/setter pair
name String
getter/setter pairinherited
position Offset?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
subtree Subtree?
getter/setter pairinherited

Methods

draw(Canvas canvas) → dynamic
override
init() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited