Node class abstract

Implementers

Constructors

Node(String name, {Size? size, Offset? position, Subtree? subtree})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
position Offset?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pair
subtree Subtree?
getter/setter pair

Methods

draw(Canvas canvas) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited