Rectangle class

Inheritance

Constructors

Rectangle(String name, Size size, Offset position, Color color, {PaintingStyle style = PaintingStyle.fill})
Rectangle.from(String name, Offset position, Size size, Color color, [dynamic style = PaintingStyle.fill])

Properties

color Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pairinherited
position Offset?
getter/setter pairinherited
rect Rect?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
getter/setter pairinherited
style PaintingStyle
getter/setter pair
subtree Subtree?
getter/setter pairinherited

Methods

draw(Canvas canvas) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited