Subtree class

Constructors

Subtree(List<Node>? children, ConnectionPoint startPoint, {double distanceFromParent = 30, double branchLength = 6, Color color = Colors.black, double strokeWidth = 2, double gapBetweenChildren = 20})

Properties

branchLength double
getter/setter pair
children List<Node>?
getter/setter pair
color Color
getter/setter pair
distanceFromParent double
getter/setter pair
gapBetweenChildren double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startPoint ConnectionPoint
getter/setter pair
strokeWidth double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited