LineChartProperties class

Constructors

LineChartProperties(double minY, double maxY)

Properties

asArea bool
getter/setter pair
curved bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxY double
final
minY double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited