Node class

Constructors

Node(Rect rect, TimeRange range, String startTime, String endTime, bool selected, Paint unselectedPaint, Paint selectedPaint)

Properties

endTime String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
paint Paint
no setter
range TimeRange
getter/setter pair
rect Rect
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pair
selectedPaint Paint
getter/setter pair
shouldRepaint bool
getter/setter pair
startTime String
getter/setter pair
unselectedPaint Paint
getter/setter pair

Methods

contains(Offset point) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggle() bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited