WidgetRegistry class

Constructors

WidgetRegistry()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetMap Map<String, Function>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerWidget(String widgetType, Function widgetFunc) → void
register or override a widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

legacyWidgetMap Map<String, Function>
Legacy: To be moved to _registeredWidgets;
no setter
pageWidgetMap Map<String, Function>
no setter