DeviceSecurity class
- Inheritance
-
- Object
- EnsembleAction
- DeviceSecurity
- Mixed-in types
-
- Invokable
Constructors
- DeviceSecurity({EnsembleAction? onSuccess, EnsembleAction? onError, String? packageName, String? signature})
Properties
- definition ↔ SourceSpan?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pairinherited
- initiator ↔ Invokable?
-
getter/setter pairinherited
- inputs ↔ Map?
-
getter/setter pairinherited
- onError ↔ EnsembleAction?
-
getter/setter pair
- onSuccess ↔ EnsembleAction?
-
getter/setter pair
- packageName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature ↔ String?
-
getter/setter pair
Methods
-
eval(
dynamic data, ScopeManager scopeManager) → dynamic -
inherited
-
execute(
BuildContext context, ScopeManager scopeManager) → Future< void> -
TODO: each Action does all the execution in here
use DataContext to eval properties. ScopeManager should be refactored
so it contains the update data context (its DataContext might not have
the latest data)
override
-
getList(
Object obj) → List? -
inherited
-
getMap(
Object obj) → Map? -
inherited
-
getMethod(
dynamic method) → Function? -
inherited
-
getProperty(
dynamic prop) → dynamic -
inherited
-
getString(
Object obj) → String? -
inherited
-
getters(
) → Map< String, Function> -
mark these functions as protected as we need the implementations,
but discourage direct usages.
Reasons:
override
-
hasGettableProperty(
dynamic prop) → bool -
inherited
-
hasMethod(
dynamic method) → bool -
inherited
-
hasSettableProperty(
dynamic prop) → bool -
inherited
-
methods(
) → Map< String, Function> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setProperty(
dynamic prop, dynamic val) → void -
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
-
setters(
) → Map< String, Function> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
{Map? payload}) → EnsembleAction?