menu
ensemble package
documentation
framework/action.dart
BaseNavigateScreenAction class
BaseNavigateScreenAction class
dark_mode
light_mode
BaseNavigateScreenAction
class
abstract
Inheritance
Object
EnsembleAction
BaseNavigateScreenAction
Implementers
NavigateExternalScreen
NavigateModalScreenAction
NavigateScreenAction
Constructors
BaseNavigateScreenAction
({
Invokable?
initiator
,
required
String
screenName
,
required
bool
asModal
,
Map
<
String
,
dynamic
>
?
transition
,
Map
<
String
,
dynamic
>
?
payload
,
Map
<
String
,
dynamic
>
?
options
,
bool
isExternal
=
false
,
bool
asExternal
=
false
})
Properties
asExternal
→
bool
final
asModal
↔
bool
getter/setter pair
hashCode
→
int
The hash code for this object.
no setter
inherited
initiator
↔ Invokable?
getter/setter pair
inherited
inputs
↔
Map
?
getter/setter pair
inherited
isExternal
→
bool
final
options
→
Map
<
String
,
dynamic
>
?
final
payload
↔
Map
<
String
,
dynamic
>
?
getter/setter pair
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
screenName
↔
String
getter/setter pair
transition
↔
Map
<
String
,
dynamic
>
?
getter/setter pair
Methods
eval
(
dynamic
data
,
ScopeManager
scopeManager
)
→ dynamic
inherited
execute
(
BuildContext
context
,
ScopeManager
scopeManager
)
→
Future
TODO: each Action does all the execution in here use DataContext to eval properties. ScopeManager should be refactored so it contains the update data context (its DataContext might not have the latest data)
inherited
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
ensemble package
documentation
framework/action
BaseNavigateScreenAction class
action library