FileUploadAction class
- Inheritance
-
- Object
- EnsembleAction
- FileUploadAction
Constructors
- FileUploadAction({Map? inputs, String? id, EnsembleAction? onComplete, EnsembleAction? onError, required String uploadApi, required String fieldName, int? maxFileSize, String? overMaxFileSizeMessage, required bool isBackgroundTask, required dynamic files, String? networkType, bool? requiresBatteryNotLow, required bool showNotification, int? batchSize})
- FileUploadAction.fromYaml({Map? payload})
-
factory
Properties
- batchSize ↔ int?
-
getter/setter pair
- fieldName ↔ String
-
getter/setter pair
- files ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- initiator ↔ Invokable?
-
getter/setter pairinherited
- inputs ↔ Map?
-
getter/setter pairinherited
- isBackgroundTask ↔ bool
-
getter/setter pair
- maxFileSize ↔ int?
-
getter/setter pair
- networkType ↔ String?
-
getter/setter pair
- onComplete ↔ EnsembleAction?
-
getter/setter pair
- onError ↔ EnsembleAction?
-
getter/setter pair
- overMaxFileSizeMessage ↔ String?
-
getter/setter pair
- requiresBatteryNotLow ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNotification ↔ bool
-
getter/setter pair
- uploadApi ↔ String
-
getter/setter pair
Methods
-
eval(
dynamic data, ScopeManager scopeManager) → dynamic -
inherited
-
execute(
BuildContext context, ScopeManager scopeManager) → Future -
TODO: each Action does all the execution in here
use DataContext to eval properties. ScopeManager should be refactored
so it contains the update data context (its DataContext might not have
the latest data)
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited