FirebaseFunctionsAPIProvider class
- Inheritance
-
- Object
- APIProvider
- FirebaseFunctionsAPIProvider
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clone(
) → FirebaseFunctionsAPIProvider -
override
-
dispose(
) → dynamic -
override
-
init(
String appId, Map< String, dynamic> config) → Future<void> -
override
-
invokeApi(
BuildContext context, YamlMap api, DataContext eContext, String apiName) → Future< Response> -
override
-
invokeMockAPI(
DataContext eContext, dynamic mock) → Future< Response> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- firebaseOptions ↔ FirebaseOptions?
-
getter/setter pair
- platformOptions → dynamic
-
no setter
Static Methods
-
getFirebaseAppContext(
) → FirebaseApp? -
initializeFirebaseAppCheck(
) → Future< void> - Initialize Firebase App Check with Firebase dependency check