FirestoreResponse class
Constructors
- FirestoreResponse({APIState apiState = APIState.idle, dynamic body, String apiName = '', bool isOkay = true})
Properties
- apiName ↔ String
-
getter/setter pairinherited
- apiState ↔ APIState
-
getter/setter pairinherited
- body ↔ dynamic
-
getter/setter pairinherited
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- isOkay ↔ bool
-
getter/setter pairinherited
- reasonPhrase ↔ String?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int?
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateState(
{required dynamic apiState}) → dynamic -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited