HostCachedEnsembleProvider class
Connecting to Ensemble-hosted definitions with a host persistent cache
- Inheritance
-
- Object
- DefinitionProvider
- EnsembleDefinitionProvider
- HostCachedEnsembleProvider
Properties
- appId → String
-
finalinherited
- appModel ↔ AppModel
-
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostCache ↔ _HostSessionCache
-
getter/setter pair
- initialForcedLocale ↔ Locale?
-
getter/setter pairinherited
- isListenerMode → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAppBundle(
{bool? bypassCache = false}) → Future< AppBundle> -
override
-
getAppConfig(
) → UserAppConfig? -
override
-
getDefinition(
{String? screenId, String? screenName}) → Future< ScreenDefinition> -
override
-
getHomeScreenName(
) → String? -
inherited
-
getI18NDelegate(
{Locale? forcedLocale}) → FlutterI18nDelegate -
inherited
-
getSecrets(
) → Map< String, String> -
override
-
getSupportedLanguages(
) → List< String> -
inherited
-
getTranslationMap(
Locale locale) → Map? -
inherited
-
init(
) → Future< EnsembleDefinitionProvider> -
inherited
-
isArtifactRefreshEnabled(
) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAppLifecycleStateChanged(
AppLifecycleState state) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
String appId, I18nProps i18nProps) → Future< HostCachedEnsembleProvider>