FileDefinitionProvider class abstract
file-based provider. Base class for both Local/Remote providers
- Inheritance
-
- Object
- DefinitionProvider
- FileDefinitionProvider
- Implementers
Constructors
- FileDefinitionProvider(String path, String appHome, {I18nProps? i18nProps, Locale? initialForcedLocale})
Properties
- appConfig ↔ UserAppConfig?
-
getter/setter pair
- appHome → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- i18nProps → I18nProps?
-
final
- initialForcedLocale ↔ Locale?
-
getter/setter pairinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAppBundle(
{bool? bypassCache = false}) → Future< AppBundle> -
inherited
-
getAppConfig(
) → UserAppConfig? -
inherited
-
getDefinition(
{String? screenId, String? screenName}) → Future< ScreenDefinition> -
inherited
-
getHomeScreenName(
) → String? -
inherited
-
getI18NDelegate(
{Locale? forcedLocale}) → FlutterI18nDelegate? -
override
-
getSecrets(
) → Map< String, String> -
override
-
getSupportedLanguages(
) → List< String> -
override
-
getTranslationLoader(
I18nProps i18nProps, {Locale? forcedLocale}) → FileTranslationLoader -
init(
) → Future< DefinitionProvider> -
inherited
-
isArtifactRefreshEnabled(
) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAppLifecycleStateChanged(
AppLifecycleState state) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
from(
String type, Map definitionsMap) → FileDefinitionProvider -
override