ValidationProvider class
This definition is used to validate an EDL. It simply uses the content passed in as the screen definition.
- Inheritance
-
- Object
- DefinitionProvider
- ValidationProvider
Constructors
- ValidationProvider(String content)
Properties
- content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialForcedLocale ↔ Locale?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAppBundle(
{bool? bypassCache = false}) → Future< AppBundle> -
override
-
getAppConfig(
) → UserAppConfig? -
override
-
getDefinition(
{String? screenId, String? screenName}) → Future< ScreenDefinition> -
override
-
getHomeScreenName(
) → String? -
override
-
getI18NDelegate(
{Locale? forcedLocale}) → FlutterI18nDelegate? -
override
-
getSecrets(
) → Map< String, String> -
override
-
getSupportedLanguages(
) → List< String> -
override
-
init(
) → Future< DefinitionProvider> -
override
-
isArtifactRefreshEnabled(
) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAppLifecycleStateChanged(
AppLifecycleState state) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited