MenuItem class
Constructors
- MenuItem(String? label, String? page, {dynamic customWidget, dynamic customActiveWidget, IconModel? activeIcon, IconModel? icon, String? iconLibrary, dynamic selected, bool floating = false, dynamic switchScreen, bool isClickable = true, String floatingAlignment = 'center', int? floatingMargin, dynamic onTap, String? onTapHaptic, required bool isExternal, dynamic visible = true, EnsembleSemantics? semantics})
Properties
- activeIcon → IconModel?
-
final
- customActiveWidget → dynamic
-
final
- customWidget → dynamic
-
final
- floating → bool
-
final
- floatingAlignment → String
-
final
- floatingMargin → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconModel?
-
final
- iconLibrary → String?
-
final
- isClickable → bool
-
final
- isExternal → bool
-
final
- label → String?
-
final
- onTap → dynamic
-
final
- onTapHaptic → String?
-
final
- page → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → dynamic
-
final
- semantics ↔ EnsembleSemantics?
-
getter/setter pair
- switchScreen → dynamic
-
final
- visible → dynamic
-
final
Methods
-
isVisible(
DataContext context) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldSwitchScreen(
DataContext context) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited