AuthenticatedUser class
an abstraction of the currently signed in User over the different Sign-in providers (firebase, auth0, ..) as well as Sign-in clients (google, apple, ...)
- Mixed-in types
-
- Invokable
Constructors
- AuthenticatedUser({SignInClient? client, SignInProvider? provider, required String? id, String? name, String? email, String? photo, Map? data, String? phoneNumber, bool? emailLVerified, String? tenantId, DateTime? creationTime, DateTime? lastSignInTime, bool isAnonymous = false})
Properties
- client → SignInClient?
-
final
- creationTime ↔ DateTime?
-
getter/setter pair
- data ↔ Map?
-
getter/setter pair
- definition ↔ SourceSpan?
-
getter/setter pairinherited
- email ↔ String?
-
getter/setter pair
- emailLVerified ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pairoverride
- isAnonymous ↔ bool
-
getter/setter pair
- lastSignInTime ↔ DateTime?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- phoneNumber ↔ String?
-
getter/setter pair
- photo ↔ String?
-
getter/setter pair
- provider ↔ SignInProvider?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tenantId ↔ String?
-
getter/setter pair
Methods
-
getList(
Object obj) → List? -
inherited
-
getMap(
Object obj) → Map? -
inherited
-
getMethod(
dynamic method) → Function? -
inherited
-
getProperty(
dynamic prop) → dynamic -
inherited
-
getString(
Object obj) → String? -
inherited
-
getters(
) → Map< String, Function> -
mark these functions as protected as we need the implementations,
but discourage direct usages.
Reasons:
override
-
hasGettableProperty(
dynamic prop) → bool -
inherited
-
hasMethod(
dynamic method) → bool -
inherited
-
hasSettableProperty(
dynamic prop) → bool -
inherited
-
methods(
) → Map< String, Function> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setProperty(
dynamic prop, dynamic val) → void -
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
-
setServerCredentials(
Map? credentials) → void -
setters(
) → Map< String, Function> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited