BluetoothManager class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
{required String deviceId, required ServiceFoundCallback onServiceFound, required DataReceivedCallback connectionState, required bool autoConnect, required int timeout}) → Future< void> -
disconnect(
{required String deviceId}) → void -
dispose(
) → void -
init(
{required BuildContext context, Invokable? initiator, EnsembleAction? onDataStream}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startScan(
{required ScanResultCallback onScanResult}) → Future -
stopScan(
) → Future< void> -
subscribe(
String characteristicId, DataReceivedCallback onDataReceive, {bool backgroundMode = false}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
turnOn(
) → Future< void> -
unSubscribe(
String characteristicId) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited