PhoneLabel enum
Values
- assistant → const PhoneLabel
- callback → const PhoneLabel
- car → const PhoneLabel
- companyMain → const PhoneLabel
- faxHome → const PhoneLabel
- faxOther → const PhoneLabel
- faxWork → const PhoneLabel
- home → const PhoneLabel
- iPhone → const PhoneLabel
- isdn → const PhoneLabel
- main → const PhoneLabel
- mms → const PhoneLabel
- mobile → const PhoneLabel
- pager → const PhoneLabel
- radio → const PhoneLabel
- school → const PhoneLabel
- telex → const PhoneLabel
- ttyTtd → const PhoneLabel
- work → const PhoneLabel
- workMobile → const PhoneLabel
- workPager → const PhoneLabel
- other → const PhoneLabel
- custom → const PhoneLabel
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PhoneLabel> - A constant List of the values in this enum, in order of their declaration.