RemoteConfig class abstract
Abstract provider for Remote Config values.
The real implementation is provided by the ensemble_remote_config module
when enabled via EnsembleModules in the starter; otherwise a stub is used.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllValues(
) → Map< String, dynamic> -
Return all currently known values, using the same typing rules as
getValue with a
nulldefault (i.e. minimal inference). -
getInfo(
) → Map< String, dynamic> - Metadata about the current Remote Config state (debugging only).
-
getValue(
String key, dynamic defaultValue) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → Future< void> - Manually trigger a refresh/fetch of Remote Config values.
-
setDefaults(
Map< String, dynamic> defaults) → Future<void> - Optionally register a map of default values.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited