RemoteConfigStub class
Stub used when the ensemble_remote_config module is not enabled.
Always returns defaultValue so expressions like ensemble.remoteConfig.my_key or ensemble.remoteConfig.get('key', 'default')
work without throwing.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllValues(
) → Map< String, dynamic> -
Return all currently known values, using the same typing rules as
getValue with a
nulldefault (i.e. minimal inference).override -
getInfo(
) → Map< String, dynamic> -
Metadata about the current Remote Config state (debugging only).
override
-
getValue(
String key, dynamic defaultValue) → dynamic -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → Future< void> -
Manually trigger a refresh/fetch of Remote Config values.
override
-
setDefaults(
Map< String, dynamic> defaults) → Future<void> -
Optionally register a map of default values.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited