framework/view/bottom_nav_page_view library
Classes
- a PageView implementation that keeps track of visited screens of a BottomNavBar. We use this to expose an onResume callback for each screen.
- This InheritedWidget enables each Page to be notified when the page is being revisited again