LabelValueItemTemplate class
- Inheritance
-
- Object
- BaseItemTemplate
- LabelValueItemTemplate
Constructors
- LabelValueItemTemplate(dynamic data, String name, dynamic value, {String? indexId, String? label, dynamic labelWidget})
Properties
- data ↔ dynamic
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexId → String
-
finalinherited
-
inheritedStyles
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- initialValue ↔ dynamic
-
getter/setter pairinherited
- label → String?
-
final
- labelWidget → dynamic
-
final
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
from(
Map? input) → LabelValueItemTemplate?