Debouncer class
Use this class to reduce excessive executions (e.g. API called too many times) using the run() method will ensure the execution happens only after the delay. Additional runs within this delay will reset the delay.
Properties
Methods
-
cancel(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
VoidCallback action) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited