NotificationUtilsMobile class
- Implemented types
Constructors
Properties
- context ↔ BuildContext?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- localNotificationsPlugin → FlutterLocalNotificationsPlugin
-
final
- onRemoteNotification ↔ EnsembleAction?
-
getter/setter pairoverride
- onRemoteNotificationOpened ↔ EnsembleAction?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleRemoteNotification(
) → void -
override
-
handleRemoteNotificationOpened(
) → void -
override
-
hasPermission(
) → Future< bool?> -
override
-
initNotifications(
) → Future< bool?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showNotification(
String title, {String? body, String? imageUrl, String? payload}) → Future< void> -
override
-
showProgressNotification(
int progress, {int? notificationId}) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited