NotificationUtilsBase class abstract
- Implementers
Constructors
- NotificationUtilsBase()
-
factory
Properties
- context ↔ BuildContext?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- onRemoteNotification ↔ EnsembleAction?
-
getter/setter pair
- onRemoteNotificationOpened ↔ EnsembleAction?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleRemoteNotification(
) → void -
handleRemoteNotificationOpened(
) → void -
hasPermission(
) → Future< bool?> -
initNotifications(
) → Future< bool?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showNotification(
String title, {String? body, String? imageUrl, String? payload}) → Future< void> -
showProgressNotification(
int progress, {int? notificationId}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited