UploadUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateFileName(
MediaType mediaType) → dynamic -
uploadFiles(
{required String taskId, required String method, required String url, required Map< String, String> headers, required Map<String, String> fields, required List<File> files, required String fieldName, bool showNotification = false, ProgressCallback? progressCallback, OnErrorCallback? onError}) → Future<HttpResponse?>