EnsembleBoxWrapper constructor
const
EnsembleBoxWrapper({
- Key? key,
- required Widget widget,
- required EnsembleBoxController boxController,
- bool ignoresPadding = false,
- bool ignoresMargin = false,
- bool ignoresDimension = false,
- double? fallbackWidth,
- double? fallbackHeight,
- EBorderRadius? fallbackBorderRadius,
Implementation
const EnsembleBoxWrapper(
{super.key,
required this.widget,
required this.boxController,
// internal widget may want to handle padding itself (e.g. ListView so
// its scrollbar lays on top of the padding and not the content)
this.ignoresPadding = false,
// sometimes our widget may register a gesture. Such gesture should not
// include the margin. This allows it to handle the margin on its own.
this.ignoresMargin = false,
// width/height maybe applied at the child, or not applicable
this.ignoresDimension = false,
this.fallbackWidth,
this.fallbackHeight,
this.fallbackBorderRadius});