TextStyleComposite class
- Inheritance
-
- Object
- WidgetCompositeProperty
- TextStyleComposite
Constructors
- TextStyleComposite(ChangeNotifier widgetController, {LinearGradient? textGradient, dynamic textAlign, TextStyle? styleWithFontFamily})
Properties
- backgroundColor ↔ Color?
-
getter/setter pair
- color ↔ Color?
-
getter/setter pair
- decoration ↔ TextDecoration?
-
getter/setter pair
- decorationColor ↔ Color?
-
getter/setter pair
- decorationStyle ↔ TextDecorationStyle?
-
getter/setter pair
- decorationThickness ↔ double?
-
getter/setter pair
- definition ↔ SourceSpan?
-
getter/setter pairinherited
- fontFamily ↔ TextStyle?
-
getter/setter pair
- fontSize ↔ int?
-
getter/setter pair
- fontWeight ↔ FontWeight?
-
getter/setter pair
- gradient ↔ LinearGradient?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pairinherited
- isItalic ↔ bool?
-
getter/setter pair
- letterSpacing ↔ double?
-
getter/setter pair
- lineHeightMultiple ↔ double?
-
getter/setter pair
- overflow ↔ TextOverflow?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textAlign ↔ TextAlign?
-
getter/setter pair
- widgetController ↔ ChangeNotifier
-
getter/setter pairinherited
- wordSpacing ↔ double?
-
getter/setter pair
Methods
-
getList(
Object obj) → List? -
inherited
-
getMap(
Object obj) → Map? -
inherited
-
getMethod(
dynamic method) → Function? -
inherited
-
getProperty(
dynamic prop) → dynamic -
inherited
-
getString(
Object obj) → String? -
inherited
-
getters(
) → Map< String, Function> -
mark these functions as protected as we need the implementations,
but discourage direct usages.
Reasons:
override
-
getTextStyle(
) → TextStyle -
hasGettableProperty(
dynamic prop) → bool -
inherited
-
hasMethod(
dynamic method) → bool -
inherited
-
hasSettableProperty(
dynamic prop) → bool -
inherited
-
methods(
) → Map< String, Function> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setProperty(
dynamic prop, dynamic val) → void -
update a property. If this is a HasController (i.e. Widget), notify it of changes
inherited
-
setters(
) → Map< String, Function> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited