AndroidTimePickerStyle class
Constructors
- AndroidTimePickerStyle({TimePickerEntryMode initialEntryMode = TimePickerEntryMode.dial, String? cancelText, String? confirmText, Orientation? orientation, Color? backgroundColor, ButtonStyle? buttonStyle, Color? dialBackgroundColor, Color? dialHandColor, Color? dialTextColor, TextStyle? dialTextStyle, double? elevation, Color? entryModeIconColor, TextStyle? helpTextStyle, Color? hourMinuteBackgroundColor, TextStyle? hourMinuteTextStyle, EdgeInsetsGeometry? padding})
Properties
- backgroundColor → Color?
-
final
-
final
- cancelText → String?
-
final
- confirmText → String?
-
final
- dialBackgroundColor → Color?
-
final
- dialHandColor → Color?
-
final
- dialTextColor → Color?
-
final
- dialTextStyle → TextStyle?
-
final
- elevation → double?
-
final
- entryModeIconColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpTextStyle → TextStyle?
-
final
- hourMinuteBackgroundColor → Color?
-
final
- hourMinuteTextStyle → TextStyle?
-
final
- initialEntryMode → TimePickerEntryMode
-
final
- orientation → Orientation?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited